@@ -78,7 +78,12 @@ class Student:
         if "Estudante não encontrado." in html:
             raise ValueError(f"Student with username '{username}' doesn't exist")
         
-        if "Problem found" in html: # the only info we can get is the name (I don't think it's even the entire name)
+        # Otherwise, it's a normal student page
+        self._load_normal_student_page(soup, use_cache)
+
+    def _load_normal_student_page(self, soup, use_cache : bool):
+        
+        if "Problem found" in str(soup): # the only info we can get is the name (I don't think it's even the entire name)
             content_soup = soup.find("div", {"id" : "conteudoinner"})
             self.name = content_soup.contents[5].string
 
@@ -88,10 +93,6 @@ class Student:
 
             return
         
-        # Otherwise, it's a normal student page
-        self._load_normal_student_page(soup, use_cache)
-
-    def _load_normal_student_page(self, soup, use_cache : bool):
         self.name = soup.find("div", {"class" : "estudante-info-nome"}).string.strip()
         
         personal_webpage_div = soup.find("div", {"class" : "pagina-pessoal"})
@@ -253,7 +254,7 @@ class Student:
 
         info["email"] = email
 
-        courses = [_parse_course_box(div) for div in soup.find_all("div", {"class" : "estudante-lista-curso-activo"})]
+        courses = [_parse_course_box(div, self.base_url) for div in soup.find_all("div", {"class" : "estudante-lista-curso-activo"})]
         info["courses"] = courses
 
         return info
@@ -306,7 +307,7 @@ class Student:
         return f"{self.name} ({self.username})"
 
 
-def _parse_course_box(bs_course_div):
+def _parse_course_box(bs_course_div, base_url):
     """Parses the the information available in the "estudante-lista-curso-activo" div.
     NOTE: Doesn't work with unpriviledged access to the student page
     It returns a dictionary like this: 
@@ -326,7 +327,7 @@ def _parse_course_box(bs_course_div):
     if name_div.a == None:  # There is no link
         course = name_div.string
     else:
-        course = _Course.Course.from_a_tag(name_div.a)
+        course = _Course.Course.from_a_tag(name_div.a, base_url=base_url)
         
     institution = bs_course_div.find("div", {"class": "estudante-lista-curso-instit"}).string
     
